@@ -151,16 +151,16 @@ impl Client {
 		Ok(self.list().await?.into_iter().map(|v| (v.name.clone(), v)).collect::<BTreeMap<_, _>>())
 	}
 
-	pub async fn add_torrent_from_link(&mut self, url: impl ToString) -> Result<AddTorrentResponse, Error> {
-		let response = self.rpc("torrent-add", 8, AddTorrent{filename: Some(url.to_string()), metainfo: None}).await?.error_for_status()?.text().await?;
+	pub async fn add_torrent_from_link(&mut self, url: &str) -> Result<AddTorrentResponse, Error> {
+		let response = self.rpc("torrent-add", 8, AddTorrent{filename: Some(url), metainfo: None}).await?.error_for_status()?.text().await?;
 		let response: Response<AddTorrentResponse> = serde_json::from_str(&response)?;
 		Ok(response.arguments)
 	}
 
-	pub async fn add_torrent(&mut self, url: impl ToString) -> Result<AddTorrentResponse, Error> {
-		let response = reqwest::get(&url.to_string()).await?.bytes().await?;
+	pub async fn add_torrent(&mut self, url: &str) -> Result<AddTorrentResponse, Error> {
+		let response = reqwest::get(url).await?.bytes().await?;
 		let torrent_data = base64::encode(&response);
-		let response = self.rpc("torrent-add", 8, AddTorrent{filename: None, metainfo: Some(torrent_data)}).await?.error_for_status()?.text().await?;
+		let response = self.rpc("torrent-add", 8, AddTorrent{filename: None, metainfo: Some(&torrent_data)}).await?.error_for_status()?.text().await?;
 		let response: Response<AddTorrentResponse> = serde_json::from_str(&response)?;
 		Ok(response.arguments)
 	}
